# Authors

<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->

**Table of Contents** _generated with [DocToc](https://github.com/thlorenz/doctoc)_

- [Authors](#authors)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->

[![image](https://img.shields.io/github/contributors/pyvista/scikit-gmsh.svg?logo=github&logoColor=white&style=for-the-badge)](https://github.com/pyvista/scikit-gmsh/graphs/contributors/)

The following is a list of authors who have made substantial
contributions to the conception or design of this software; or the
creation of new code used in this software; or have drafted the work or
substantively revised it and are considered \"The scikit-gmsh
Developers\":

[![contrib.rocks](https://contrib.rocks/image?repo=pyvista/scikit-gmsh)](https://github.com/pyvista/scikit-gmsh/graphs/contributors)

Made with [contrib rocks](https://contrib.rocks).
